--[[

Version 0.01 - Initial release of Concept code to wowace svn

Author : Levva of EU Khadgar 
	
--]]

local L = LibStub("AceLocale-3.0"):GetLocale("QuestItem")
local AceAddon = LibStub("AceAddon-3.0")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");
QuestItem = AceAddon:NewAddon("QuestItem", "AceConsole-3.0", "AceEvent-3.0")
local REVISION = tonumber(("$Revision: 2 $"):match("%d+"))

QuestItem.BagFrame = CreateFrame("Frame", "QuestItemBase", UIParent)

QuestItem.textures = {}
QuestItem.borders = {}
QuestItem.fonts = {}
QuestItem.sounds = {}
QuestItem.barBackdrop = {
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	}
QuestItem.frameBackdrop ={
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		--edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
	}

-------------------
-- Config details
-------------------

QuestItem.defaults = {
	char = {
		message = "Welcome Home!",
		relativeTo = "UIParent",
		relativePoint = "CENTER",
		point = "CENTER",
		texture = "Blizzard",
		msgfont = "Friz Quadrata TT",
		msgfontsize = 24,
		msgfonteffect = "none",
		border = "None",
		barborder = "Blizzard Tooltip",
		xOffset = 0,
		yOffset = 0,
		fWidth = 300,
		fHeight = 175,
		scale = 1,
		debug = false,
	}
}

-----------------------------------------
-- Initialisation & Startup Routines
-----------------------------------------

function QuestItem:OnInitialize()
	local AceConfigReg = LibStub("AceConfigRegistry-3.0")
	local AceConfigDialog = LibStub("AceConfigDialog-3.0")

	self.db = LibStub("AceDB-3.0"):New("QuestItemDBPC", QuestItem.defaults, "char")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("QuestItem", self:GetOptions(), {"questitem", "qi"} )
	media.RegisterCallback(self, "LibSharedMedia_Registered")
	
	-- Add the options to blizzard frame (add them backwards so they show up in the proper order
	self.optionsFrame = AceConfigDialog:AddToBlizOptions("QuestItem","QuestItem")
	self.optionsFrame[L["About"]] = LibStub("LibAboutPanel").new("QuestItem", "QuestItem")
	self.db:RegisterDefaults(self.defaults)
	local version = GetAddOnMetadata("QuestItem","Version")
	self.version = ("QuestItem v%s (r%s)"):format(version, REVISION)
	self:Print(self.version.." Loaded.")
end

function QuestItem:OnDisable()
    -- Called when the addon is disabled
end

function QuestItem:OnEnable()
	self:LibSharedMedia_Registered()
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("UPDATE_BINDINGS")
end

function QuestItem:LibSharedMedia_Registered()
	for k, v in pairs(media:List("statusbar")) do
		self.textures[v] = v
	end
	for k, v in pairs(media:List("border")) do
		self.borders[v] = v
	end
	for k, v in pairs(media:List("font")) do
		self.fonts[v] = v
	end
	for k, v in pairs(media:List("sound")) do
		self.sounds[v] = v
	end
end

----------------------
-- Event Routines
----------------------

function QuestItem:PLAYER_ENTERING_WORLD()
	self:CreateBagFrame()
	self:UpdateBagFrame()
end

function QuestItem:UPDATE_BINDINGS()
--~ 	self:UpdateBindings()
end

----------------------
-- Frame Routines
----------------------

function QuestItem:CreateBagFrame()
	self.BagFrame:SetScale(self.db.char.scale)
	self.BagFrame:SetFrameStrata("BACKGROUND")
	self.BagFrame:SetWidth(self.db.char.fWidth + self.db.char.fHeight / 7)
	self.BagFrame:SetHeight(self.db.char.fHeight)
	self.BagFrame:SetBackdrop(self.frameBackdrop)
	self.BagFrame:SetBackdropColor(1, 1, 1, 0)
	self.BagFrame:SetMovable(true)
	self.BagFrame:RegisterForDrag("LeftButton")
	self.BagFrame:SetPoint(self.db.char.point, self.db.char.relativeTo, self.db.char.relativePoint, self.db.char.xOffset, self.db.char.yOffset)
	self.BagFrame:SetScript("OnDragStart", 
		function()
			self.BagFrame:StartMoving();
		end );
	self.BagFrame:SetScript("OnDragStop",
		function()
			self.BagFrame:StopMovingOrSizing();
			self.BagFrame:SetScript("OnUpdate", nil);
			self:FinishedMoving(self.db.char, self.BagFrame);
		end );
	self.BagFrame:Show()
end

function QuestItem:UpdateBagFrame()
	-- check all items in bags and add to quest bag frame 
	for bag = 0,4 do
		for slot = 1, GetContainerNumSlots(bag) do
			local itemLink = GetContainerItemLink(bag, slot)
			if itemLink then -- check if its a quest item
				local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture = GetItemInfo(itemLink)
				if itemType == L["Quest"] then
					self:Print(itemName.." found in bag - its a quest item")
				end
			end
		end
    end
end